==> pandoc-3.7.0.2.tar.gz: pandoc-3.7.0.2/AUTHORS.md <==
# Contributors

- Aaron Wolen
- Adelar da Silva Queiróz
- Agustín Martín Barbero
- Akash Patel
- Akos Marton
- Albert Krewinkel
- Alex Ivkin
- Alex Toldaiev
- Alex Vong
- Alexander Batischev
- Alexander Kondratskiy
- Alexander Krotov
- Alexander Sulfrian
- Alexander V Vershilov
- Alexandre Franke
- Alfred Wechselberger
- Amar Al-Zubaidi
- Amir Dekel
- Amneesh Singh
- Amogh Rathore
- Amy de Buitléir
- Anabra
- Anders Waldenborg
- Andreas Deininger
- Andreas Lööw
- Andreas Scherer
- Andres Freund
- Andrew Dunning
- Andy Morris
- Aner Lucero
- Anti-Distinctlyminty
- Antoine Latter
- Antonio Terceiro
- Arata Mizuki
- Arata Mizuki
- Arfon Smith
- Arlo O'Keeffe
- Artem Pelenitsyn
- Artyom Kazak
- B. Scott Michel
- Bastien Dumont
- Ben Firshman
- Ben Gamari
- Ben Steinberg
- Beni Cherniavsky-Paskin
- Benjamin Bray
- Benjamin Esham
- Benjamin Wuethrich
- Benoit Schweblin
- Benson Muite
- Bjorn Buckwalter
- Blake Eryx
- Bodigrim
- Bradley Kuhn
- Brent Yorgey
- Brian Leung
- Bryan O'Sullivan
- Caleb McDaniel
- Caleb Mclennan
- Calvin Beck
- Carlos Scheidegger
- Carlos Sosa
- Carsten Allefeld
- Castedo Ellerman
- Cécile Chemin
- Cédric Couralet
- Cezary Drożak
- Chandrahas77
- Charanjit Singh
- Charles Tapley Hoyt
- Charlotte Koch
- Chris Black
- Christian Conkle
- Christian Christiansen
- Christian Despres
- Christoffer Ackelman
- Christoffer Sawicki
- Christophe Dervieux
- Clare Macrae
- Clint Adams
- Conal Elliott
- Cormac Relf
- Craig S. Bosma
- Damien Clochard
- Daniel Bergey
- Daniel Kessler
- Daniel Maslowski
- Daniel T. Staal
- Daniele D'Orazio
- David A Roberts
- David Lazar
- David Martschenko
- David Röthlisberger
- Denis Laxalde
- Denis Maier
- Derek Chen-Becker
- Diego Balseiro
- Diogo Almiro
- Dimitri Sabadie
- Dimitris Apostolou
- Dmitry Pogodin
- Dmitry Volodin
- Douglas Calvert
- Edwin Török
- Eigil Rischel
- Elliot Bobrow
- Emanuel Evans
- Emerson Harkin
- Emily Bourke
- Emily Eisenberg
- Eric Kow
- Eric Schrijver
- Eric Seidel
- Erik Rask
- Ethan Riley
- Étienne Bersac
- Evan Silberman
- Even Brenden
- Ezwal
- Fabián Heredia Montiel
- Félix Baylac-Jacqué
- Felix Yan
- Florian Beeres
- Florian Eitel
- Florian Klink
- Florian Kohrt
- Francesco Mazzoli
- Francesco Occhipinti
- François Gannaz
- Frank Seifferth
- Frederik Elwert
- Freiric Barral
- Freirich Raabe
- Frerich Raabe
- Fyodor Sheremetyev
- Gabor Pali
- Gabriel Lewertowski
- Gavin Beatty
- George Stagg
- Georgi Lyubenov
- GHyman83
- Gokul Rajiv
- Gordon Woodhull
- Gottfried Haider
- Greg Maslov
- Greg Rundlett
- Grégory Bataille
- Guriy Samarin
- Gwern Branwen
- Hamish Mackenzie
- Hans-Peter Deifel
- Hendrik Erz
- Heiko Schlittermann
- Henrik Tramberend
- Henry de Valence
- Herwig Stuetz
- Hikaru Ibayashi
- Hos Es
- Hubert Plociniczak
- Iacobus1983
- Ian Max Andolina
- Igor Khorlo
- Igor Pashev
- Ilona Silverwood
- Ilya V. Portnov
- Ivan Panchenko
- Ivan Trubach
- Ivar de Bruin
- Ivo Clarysse
- Jaap de Jong
- James J Balamuta
- J. B. Rainsberger
- J. Lewis Muir
- Jackson Schuster
- Jaehwang Jung
- Jaime Marquínez Ferrándiz
- Jake Zimmerman
- Jakob Voß
- James Aspnes
- James P. Ascher
- James Scott-Brown
- Jamie F. Olson
- Jan Larres
- Jan Schulz
- Jan Tojnar
- Jannik Buhr
- Jan-Otto Kröpke
- Jared Lander
- Jason Ronallo
- Jeff Arnold
- Jeff Runningen
- Jens Getreu
- Jens Petersen
- Jens Oehlschlägel
- Jesse Hathaway
- Jeremie Knuesel
- Jérémy Bobbio
- Jeroen de Haas
- Jerry Sky
- Jesse Rosenthal
- Jez Cope
- Joe Hermaszewski
- Joe Hillenbrand
- John KetzerX
- John Luke Bentley
- John MacFarlane
- John Muccigrosso
- John Purnell
- Jonas Scholl
- Jonas Smedegaard
- Jonathan
- Jonathan Daugherty
- Jonathan Dönszelmann
- Jose Luis Duran
- José de Mattos Neto
- Josef Svenningsson
- Joseph C. Sible
- Julia Diaz
- Julien Cretel
- Julien Dutant
- Juliette Fourcot
- Juliusz Gonera
- Justin Bogner
- Justin Wood
- Karl Pettersson
- Keiichiro Shikano
- Kelsey Hightower
- Kevin Broch
- Kolen Cheung
- Konstantin Zudov
- Kristof Bastiaensen
- Krystof Beuermann
- Lars-Dominik Braun
- Laurent P. René de Cotret
- Lawrence Chonavel
- Leif Metcalf
- Leo Heitmann Ruiz
- Leonard Rosenthol
- Lila
- Link Swanson
- Loïc Grobol
- Lorenzo
- Lucas Escot
- Lucas Viana
- Lucas V. R
- Luis Rivera
- Luke Plant
- Manolis Stamatogiannakis
- Marc Schreiber
- Marcin Serwin
- Mario Lang
- Mark Gardner
- Mark Szepieniec
- Mark Wright
- Martin Joerg
- Martin Linn
- Martin Michlmayr
- Martín Pozo
- Masataka Ogawa
- Masayoshi Takahashi
- Matej Kollar
- Mathias Schenner
- Mathias Walter
- Mathieu Boespflug
- Mathieu Duponchelle
- Matt Dodson
- Matthew Doty
- Matthew Eddey
- Matthew Pickering
- Matthias C. M. Troffaes
- Mauro Bieg
- Max Bolingbroke
- Max Heller
- Max Rydahl Andersen
- Merijn Verstraaten
- Michael Beaumont
- Michael Chladek
- Michael Hoffmann
- Michael McClurg
- Michael Peyton Jones
- Michael Reed
- Michael Snoyman
- Michael Stahl
- Michael Thompson
- Mickaël Canouil
- Mike Tzou
- Mikołaj Machowski
- Milan Bracke
- MinRK
- Mohamed Akram
- Morgan Willcock
- Morton Fox
- Nathan Gass
- Naveen
- Neil Mayhew
- Nick Bart
- Nick Berendsen
- Nick Fleisher
- Nicolas Kaiser
- Niklas Eicker
- Nikolai Korobeinikov
- Nikolay Yakimov
- Nils Carlson
- Nixon Enraght-Moony
- Noah Malmed
- Nokome Bentley
- Norwid Behrnd
- OCzarnecki
- Ola Wolska
- Ole Martin Ruud
- Oliver Fabel
- Oliver Matthews
- Olivier Benz
- Olivier Dossmann
- Ophir Lifshitz
- Or Neeman
- OvidiusCicero
- Owen McGrath
- Pablo Rodríguez
- Pascal Wagler
- Pau RE
- Paul Rivier
- Paul Tilley
- Paulo Tanimoto
- Pavol Otto
- Per Christian Gaustad
- Pete Ryland
- Peter Fabinksi
- Peter Wang
- Philip Pesca
- Philippe Ombredanne
- Phillip Alday
- Pranesh Prakash
- Prat
- Prayag Verma
- Puneeth Chaganti
- Quinn
- R. N. West
- Ralf Stephan
- Raniere Silva
- Raymond Ehlers
- Recai Oktaş
- Rowan Rodrik van der Molen
- Roland Hieber
- Roman Beránek
- Ruqi
- RyanGlScott
- S.P.H
- Salim B
- Sam S. Almahri
- Sam May
- Samuel Tardieu
- Saumel Lemmenmeier
- Santiago Zarate
- Sascha Wilde
- Scott Morrison
- Sebastian Talmon
- Sebbones
- Sen-wen Deng
- Sergei Trofimovich
- Sergey Astanin
- Seth Speaks
- Shahbaz Youssefi
- Shaun Attfield
- Shim Myeongseob
- Shin Sang-jae
- Sidarth Kapur
- Sidharth Kapur
- Simon Hengel
- Simon Schuster
- Siphalor
- Stefan Dresselhaus
- Stephan Daus
- Stephan Meijer
- Stephen Altamirano
- Stephen Huan
- Stephen Reindl
- Stéphane Guillou
- Sukil Etxenike
- Sukka
- Sumit Sahrawat
- Suraj Patil
- Sven Wick
- TEC
- Tarik Graba
- Tatiana Porras
- Terence Eden
- Thenaesh Elango
- Thomas Hodgson
- Thomas Soeiro
- Thomas Weißschuh
- Tiago-Manzato
- Tim Lin
- Tim Stewart
- Tim Wisotzki
- Timm Albers
- Timothy Humphries
- Tiziano Müller
- Todd Sifleet
- Tomas Dahlqvist
- TomBen
- Tom Leese
- Toni Dietze
- Tristan Stenner
- Tristan de Cacqueray
- Tristano Ajmone
- Tuong Nguyen Manh
- Uli Köhler
- Urs Liska
- Václav Haisman
- Václav Zeman
- Vaibhav Sagar
- Vanessa McHale
- Vasily Alferov
- Veratyr
- Viktor Kronvall
- Vincent
- Vlad Hanciuta
- Vladimir Alexiev
- Waldir Pimenta
- Wandmalfarbe
- Wentao Han
- Wikiwide
- William Lupton
- William Rusnack
- Winnie Hellmann
- Wout Gevaert
- Xavier Olive
- Yan Pashkovsky
- Yehuda Katz
- YI
- Yoan Blanc
- Yuchen Pei
- Zihang Chen
- 3w36zj6
- arcnmx
- a-vrma
- andrebauer
- black-desk
- blmage
- bucklereed
- bumper314
- chinapedia
- cholonam
- closeobserve
- csforste
- d-dorazio
- damon-sava-stanley
- dbecher-ito
- ebiim
- ech0
- etclub
- favonia
- guqicun
- harabat
- hseg
- infinity0x
- jeongminkim-islab
- josch
- kaizshang91
- lawcho
- lifeunleaded
- lux-lth
- luz paz
- lwolfsonkin
- mbracke
- mbrackeantidot
- mh4ckt3mh4ckt1c4s
- mjfs
- mt_caret
- nbehrnd
- niszet
- nkalvi
- nuew
- obcat
- oltolm
- oquechy
- pacien
- perro tuerto
- piq9117
- priiduonu
- qerub
- quasicomputational
- ricnorr
- robabla
- roblabla
- rodja.trappe
- rski
- samuel-weinhardt
- sdhoward
- shreevatsa.public
- takahashim
- taotieren
- tecosaur
- tgkokk
- the-solipsist
- thomjur
- thsutton
- thron7
- timo-a
- vijayphoenix
- vkraven
- wgevaert
- wiefling
- willj-dev
- wuffi

==> pandoc-3.8.2.1.tar.gz: pandoc-3.8.2.1/AUTHORS.md <==
# Contributors

- Aaron Wolen
- Adelar da Silva Queiróz
- Agustín Martín Barbero
- Akash Patel
- Akos Marton
- Albert Krewinkel
- Alex Ivkin
- Alex Toldaiev
- Alex Vong
- Alexander Batischev
- Alexander Kondratskiy
- Alexander Krotov
- Alexander Sulfrian
- Alexander V Vershilov
- Alexandre Franke
- Alfred Wechselberger
- Amar Al-Zubaidi
- Amir Dekel
- Amneesh Singh
- Amogh Rathore
- Amy de Buitléir
- Anabra
- Anders Waldenborg
- Andreas Deininger
- Andreas Lööw
- Andreas Scherer
- Andres Freund
- Andrew Dunning
- Andy Morris
- Aner Lucero
- Anti-Distinctlyminty
- Antoine Latter
- Antonio Terceiro
- Arata Mizuki
- Arata Mizuki
- Arfon Smith
- Arlo O'Keeffe
- Artem Pelenitsyn
- Artyom Kazak
- B. Scott Michel
- Bastien Dumont
- Ben Firshman
- Ben Gamari
- Ben Steinberg
- Beni Cherniavsky-Paskin
- Benjamin Bray
- Benjamin Esham
- Benjamin Wuethrich
- Benoit Schweblin
- Benson Muite
- Bjorn Buckwalter
- Blake Eryx
- Bodigrim
- Bradley Kuhn
- Brent Yorgey
- Brian Leung
- Bryan O'Sullivan
- Caleb McDaniel
- Caleb Mclennan
- Calvin Beck
- Carlos Scheidegger
- Carlos Sosa
- Carsten Allefeld
- Castedo Ellerman
- Cécile Chemin
- Cédric Couralet
- Cezary Drożak
- Chandrahas77
- Charanjit Singh
- Charles Tapley Hoyt
- Charlotte Koch
- Chris Black
- Christian Conkle
- Christian Christiansen
- Christian Despres
- Christoffer Ackelman
- Christoffer Sawicki
- Christophe Dervieux
- Christopher Kenny
- Clare Macrae
- Clint Adams
- Conal Elliott
- Cormac Relf
- Craig S. Bosma
- Damien Clochard
- Daniel Bergey
- Daniel Kessler
- Daniel Maslowski
- Daniel T. Staal
- Daniele D'Orazio
- David A Roberts
- David Lazar
- David Martschenko
- David Röthlisberger
- Denis Laxalde
- Denis Maier
- Derek Chen-Becker
- Diego Balseiro
- Diogo Almiro
- Dimitri Sabadie
- Dimitris Apostolou
- Dmitry Pogodin
- Dmitry Volodin
- Douglas Calvert
- Edwin Török
- Eigil Rischel
- Elliot Bobrow
- Emanuel Evans
- Emmanuel Ferdman
- Emerson Harkin
- Emily Bourke
- Emily Eisenberg
- Eric Kow
- Eric Schrijver
- Eric Seidel
- Erik Post
- Erik Rask
- Ethan Riley
- Étienne Bersac
- Evan Silberman
- Even Brenden
- Ezwal
- Fabián Heredia Montiel
- Félix Baylac-Jacqué
- Felix Yan
- Florian Beeres
- Florian Eitel
- Florian Klink
- Florian Kohrt
- FoxChillz
- Francesco Mazzoli
- Francesco Occhipinti
- François Gannaz
- Frank Seifferth
- Frederik Elwert
- Freiric Barral
- Freirich Raabe
- Frerich Raabe
- Fyodor Sheremetyev
- Gabor Pali
- Gabriel Lewertowski
- Gavin Beatty
- George Stagg
- Georgi Lyubenov
- GHyman83
- Gokul Rajiv
- Gordon Woodhull
- Gottfried Haider
- Greg Maslov
- Greg Rundlett
- Grégory Bataille
- Guriy Samarin
- Gwern Branwen
- Hamish Mackenzie
- Hans-Peter Deifel
- Hendrik Erz
- Heiko Schlittermann
- Henrik Tramberend
- Henry de Valence
- Herwig Stuetz
- Hikaru Ibayashi
- Hos Es
- Hubert Plociniczak
- Iacobus1983
- Ian Max Andolina
- Igor Khorlo
- Igor Pashev
- Ilona Silverwood
- Ilya V. Portnov
- Ivan Panchenko
- Ivan Trubach
- Ivar de Bruin
- Ivo Clarysse
- Jaap de Jong
- James J Balamuta
- J. B. Rainsberger
- J. Lewis Muir
- Jackson Schuster
- Jaehwang Jung
- Jaime Marquínez Ferrándiz
- Jake Zimmerman
- Jakob Voß
- James Aspnes
- James P. Ascher
- James Scott-Brown
- Jamie F. Olson
- Jan Larres
- Jan Schulz
- Jan Tojnar
- Jannik Buhr
- Jan-Otto Kröpke
- Jared Lander
- Jason Ronallo
- Jeff Arnold
- Jeff Runningen
- Jens Getreu
- Jens Petersen
- Jens Oehlschlägel
- Jesse Hathaway
- Jeremie Knuesel
- Jérémy Bobbio
- Jeroen de Haas
- Jerry Sky
- Jesse Rosenthal
- Jez Cope
- Joe Hermaszewski
- Joe Hillenbrand
- John KetzerX
- John Luke Bentley
- John MacFarlane
- John Muccigrosso
- John Purnell
- Jonas Scholl
- Jonas Smedegaard
- Jonathan
- Jonathan Daugherty
- Jonathan Dönszelmann
- Jose Luis Duran
- José de Mattos Neto
- Josef Svenningsson
- Joseph C. Sible
- Julia Diaz
- Julien Cretel
- Julien Dutant
- Juliette Fourcot
- Juliusz Gonera
- Justin Bogner
- Justin Wood
- Karl Pettersson
- Keiichiro Shikano
- Kelsey Hightower
- Kevin Broch
- Kolen Cheung
- Konstantin Zudov
- Kristof Bastiaensen
- Krystof Beuermann
- Lars-Dominik Braun
- Laurent P. René de Cotret
- Lawrence Chonavel
- Leif Metcalf
- Leo Heitmann Ruiz
- Leonard Rosenthol
- Lila
- Link Swanson
- Loïc Grobol
- Lorenzo
- Lucas Escot
- Lucas Viana
- Lucas V. R
- Luis Rivera
- Luke Plant
- Manolis Stamatogiannakis
- Marc Schreiber
- Marcin Serwin
- Mario Lang
- Mark Gardner
- Mark Szepieniec
- Mark Wright
- Martin Joerg
- Martin Linn
- Martin Michlmayr
- Martín Pozo
- Masataka Ogawa
- Masayoshi Takahashi
- Matej Kollar
- Mathias Schenner
- Mathias Walter
- Mathieu Boespflug
- Mathieu Duponchelle
- Matt Dodson
- Matthew Doty
- Matthew Eddey
- Matthew Pickering
- Matthias C. M. Troffaes
- Mauro Bieg
- Max Bolingbroke
- Max Heller
- Max Rydahl Andersen
- Merijn Verstraaten
- Michael Beaumont
- Michael Chladek
- Michael Hoffmann
- Michael McClurg
- Michael Peyton Jones
- Michael Reed
- Michael Snoyman
- Michael Stahl
- Michael Thompson
- Mickaël Canouil
- Mike Tzou
- Mikołaj Machowski
- Milan Bracke
- MinRK
- Mohamed Akram
- Morgan Willcock
- Morton Fox
- Nathan Gass
- Naveen
- Neil Mayhew
- Nick Bart
- Nick Berendsen
- Nick Fleisher
- Nicolas Kaiser
- Niklas Eicker
- Nikolai Korobeinikov
- Nikolay Yakimov
- Nils Carlson
- Nixon Enraght-Moony
- Noah Malmed
- Nokome Bentley
- Norwid Behrnd
- OCzarnecki
- Ola Wolska
- Ole Martin Ruud
- Oliver Fabel
- Oliver Matthews
- Olivier Benz
- Olivier Dossmann
- Ophir Lifshitz
- Or Neeman
- OvidiusCicero
- Owen McGrath
- Pablo Rodríguez
- Pascal Wagler
- Pau RE
- Paul Rivier
- Paul Tilley
- Paulo Tanimoto
- Pavol Otto
- Per Christian Gaustad
- Pete Ryland
- Peter Fabinksi
- Peter Wang
- Philip Pesca
- Philippe Ombredanne
- Phillip Alday
- Pranesh Prakash
- Prat
- Prayag Verma
- Puneeth Chaganti
- Quinn
- R. N. West
- Ralf Stephan
- Raniere Silva
- Raymond Berger
- Raymond Ehlers
- Recai Oktaş
- Repetitive
- Reuben Thomas
- Rowan Rodrik van der Molen
- Roland Hieber
- Roman Beránek
- Ruqi
- RyanGlScott
- Ryan Gibb
- S.P.H
- Salim B
- Sam S. Almahri
- Sam May
- Samuel Tardieu
- Saumel Lemmenmeier
- Santiago Zarate
- Sascha Wilde
- Scott Morrison
- Sean Soon
- Sebastian Talmon
- Sebbones
- Sen-wen Deng
- Sergei Trofimovich
- Sergey Astanin
- Seth Speaks
- Shahbaz Youssefi
- Shaun Attfield
- Shim Myeongseob
- Shin Sang-jae
- Sidarth Kapur
- Sidharth Kapur
- Simon Hengel
- Simon Schuster
- Siphalor
- Stefan Dresselhaus
- Stephan Daus
- Stephan Meijer
- Stephen Altamirano
- Stephen Huan
- Stephen Reindl
- Stéphane Guillou
- Sukil Etxenike
- Sukka
- Sumit Sahrawat
- Suraj Patil
- Sven Wick
- TEC
- Tarik Graba
- Tatiana Porras
- Terence Eden
- Thenaesh Elango
- Thomas Hodgson
- Thomas Soeiro
- Thomas Weißschuh
- Tiago-Manzato
- Tim Lin
- Tim Stewart
- Tim Wisotzki
- Timm Albers
- Timothy Humphries
- Tiziano Müller
- Todd Sifleet
- Tomas Dahlqvist
- TomBen
- Tom Leese
- Toni Dietze
- Tristan Stenner
- Tristan de Cacqueray
- Tristano Ajmone
- Tuong Nguyen Manh
- Uli Köhler
- Urs Liska
- Václav Haisman
- Václav Zeman
- Vaibhav Sagar
- Vanessa McHale
- Vasily Alferov
- Veratyr
- Viktor Kronvall
- Vincent
- Vlad Hanciuta
- Vladimir Alexiev
- Waldir Pimenta
- Wandmalfarbe
- Wentao Han
- Wikiwide
- William Lupton
- William Rusnack
- Winnie Hellmann
- Wout Gevaert
- Xavier Olive
- Yan Pashkovsky
- Yehuda Katz
- YI
- Yoan Blanc
- Yuchen Pei
- Zihang Chen
- 3w36zj6
- arcnmx
- a-vrma
- andrebauer
- black-desk
- blmage
- bucklereed
- bumper314
- chinapedia
- cholonam
- closeobserve
- csforste
- d-dorazio
- damon-sava-stanley
- dbecher-ito
- ebiim
- ech0
- etclub
- favonia
- guqicun
- harabat
- hseg
- infinity0x
- jeongminkim-islab
- josch
- kaizshang91
- lawcho
- lifeunleaded
- lux-lth
- luz paz
- lwolfsonkin
- massifrg
- mbracke
- mbrackeantidot
- mh4ckt3mh4ckt1c4s
- mjfs
- mt_caret
- nbehrnd
- niszet
- nkalvi
- nuew
- obcat
- oltolm
- oquechy
- pacien
- perro tuerto
- piq9117
- priiduonu
- qerub
- quasicomputational
- reptee
- ricnorr
- robabla
- roblabla
- rodja.trappe
- rski
- samuel-weinhardt
- sdhoward
- shreevatsa.public
- takahashim
- taotieren
- tecosaur
- tgkokk
- the-solipsist
- thomjur
- thsutton
- thron7
- timo-a
- vijayphoenix
- vkraven
- wgevaert
- wiefling
- willj-dev
- wuffi
